#!/usr/bin/env python2
# -*- coding: utf-8 -*-
##################################################
# GNU Radio Python Flow Graph
# Title: Top Block
# Generated: Mon Jan 18 14:03:47 2016
##################################################

import time

from gnuradio import blocks
from gnuradio import eng_notation
from gnuradio import gr
from gnuradio.eng_option import eng_option
from gnuradio.filter import firdes
from optparse import OptionParser
import osmosdr

import numpy as np

class top_block(gr.top_block):

    def __init__(self):
        gr.top_block.__init__(self, "Top Block")

        ##################################################
        # Variables
        ##################################################
        self.time = time = 60
        self.samp_rate = samp_rate = 2e6
        self.freq = freq = 868e6

        ##################################################
        # Blocks
        ##################################################
        self.osmosdr_source_0 = osmosdr.source( args="numchan=" + str(1) + " " + "" )
        self.osmosdr_source_0.set_sample_rate(samp_rate)
        self.osmosdr_source_0.set_center_freq(freq, 0)
        self.osmosdr_source_0.set_freq_corr(0, 0)
        self.osmosdr_source_0.set_dc_offset_mode(0, 0)
        self.osmosdr_source_0.set_iq_balance_mode(0, 0)
        self.osmosdr_source_0.set_gain_mode(False, 0)
        self.osmosdr_source_0.set_gain(0, 0)
        self.osmosdr_source_0.set_if_gain(20, 0)
        self.osmosdr_source_0.set_bb_gain(20, 0)
        self.osmosdr_source_0.set_antenna("", 0)
        self.osmosdr_source_0.set_bandwidth(0, 0)

        self.blocks_head_0 = blocks.head(gr.sizeof_gr_complex*1, int(samp_rate)*time)
        self.blocks_file_sink_0 = blocks.file_sink(gr.sizeof_gr_complex*1, "/home/meise/tmp/sample.iq", False)
        self.blocks_file_sink_0.set_unbuffered(False)

        ##################################################
        # Connections
        ##################################################
        self.connect((self.blocks_head_0, 0), (self.blocks_file_sink_0, 0))
        self.connect((self.osmosdr_source_0, 0), (self.blocks_head_0, 0))

    def get_time(self):
        return self.time

    def set_time(self, time):
        self.time = time
        self.blocks_head_0.set_length(int(self.samp_rate)*self.time)

    def get_samp_rate(self):
        return self.samp_rate

    def set_samp_rate(self, samp_rate):
        self.samp_rate = samp_rate
        self.blocks_head_0.set_length(int(self.samp_rate)*self.time)
        self.osmosdr_source_0.set_sample_rate(self.samp_rate)

    def get_freq(self):
        return self.freq

    def set_freq(self, freq):
        self.freq = freq
        self.osmosdr_source_0.set_center_freq(self.freq, 0)


def count_samples():
    file_path = "/home/meise/tmp/sample.iq"

    # convert file into pynum array and use a memory map
    f = np.memmap(open(file_path), mode="r", dtype=np.complex64)

    return len(f)

def main(top_block_cls=top_block, options=None):
    tb = top_block_cls()
    tb.start()
    tb.wait()


if __name__ == '__main__':
    measurements = []

    for i in range(0, 10):
        m = {}
        m['start_time'] = time.clock()
        main()
        m['end_time'] =  time.clock()

        m['running_time'] = m['end_time']-m['start_time']
        m['samples_count'] = count_samples()
        m['count'] = i+1
        m['expacted_time'] = 60

        measurements.append(m)

    for m in measurements:
        print("%s;%s;%s;%s;%s;%s" % (m['count'], \
                                  m['running_time'], \
                                  m['samples_count'], \
                                  m['start_time'], \
                                  m['end_time'],
                                  m['expacted_time']))
